///////////////////////////////////////////////////////////
// Company         : Micro Digital                       //
// Address         : Office # C7 Raza Plaza              //
//                   DAV College Road                    //
//                   Rawalpindi,                         //
//                   Pakistan.                           //
// Programmed By   : Rashid Mehmood                      //
// Project Name    : 8051 Digital Clock On               //
//                   7 Segment (Non Multiplexed)         //
// Crystal         : 24.000000 MHz                       //
// Microcontroller : AT89C51-C52-C55-S51-S52             //
///////////////////////////////////////////////////////////

#include <AT89X51.H>
#include <stdio.h>
#include "Display.h"

// Keys definition.
#define MIN_KEY 		0X0001
#define MIN_KEY_HOLD 	0X0100
#define HOUR_KEY 		0X0002
#define HOUR_KEY_HOLD 	0X0200

#include "Port.h"
#include "Timer0.h"

// This function initializes
// sytem.
void InitSystem()
{
	// Initialize Timer0 for clock.
	InitTimer0();
}

void main()
{
	short PrevSec = -1;
	struct Time time;
	short Keys;

	// Flag to note that
	// time is changed by
	// user.
	short bChanged = 0;
	InitSystem();
	while(1)
	{
		// Get current system time.
		GetTime(&time);

		// If time changed then update it
		// on display.
		if(time.Sec != PrevSec || bChanged)
		{
			PrevSec = time.Sec;
			Display(time.Hour, time.Min);
		}
		
		// Update second indicator.
		SecIndicator = IsHalfSec();

		// Reset changed flag.
		bChanged = 0;

		// Read keys status from
		// P3_7 and P1_7 pins.
		Keys = P3_7;
		Keys <<= 1;
		Keys |= P1_7;
		
		// Pass this keys status
		// to getkeyex function.
		switch(getkeyex(Keys))
		{
		// If Minutes button pressed or hold.
		case MIN_KEY:
		case MIN_KEY_HOLD:
			time.Sec = 0;
			time.Min ++;
			if(time.Min > 59)
				time.Min = 0;
			SetSecond(time.Sec);
			SetMinute(time.Min);
			bChanged = 1;
			break;
		// If Hours button pressed or hold.
		case HOUR_KEY:
		case HOUR_KEY_HOLD:
			time.Hour ++;
			if(time.Hour > 23)
				time.Hour = 0;
			SetHour(time.Hour);
			bChanged = 1;
			break;
		}
	}
}

